@@ -1,32 +1,30 @@
-package DBIx::Class::Schema::Loader::RelBuilder::Compat::v0_07;
+package DBIx::Class::Schema::Loader::RelBuilder::Compat::v0_06;
 
 use strict;
 use warnings;
-use base 'DBIx::Class::Schema::Loader::RelBuilder';
+use base 'DBIx::Class::Schema::Loader::RelBuilder::Compat::v0_07';
 use mro 'c3';
 
+our $VERSION = '0.07016';
+
+sub _normalize_name {
+    my ($self, $name) = @_;
+
+    $name = $self->_sanitize_name($name);
+
+    return lc $name;
+}
+
 =head1 NAME
 
-DBIx::Class::Schema::Loader::RelBuilder::Compat::v0_07 - RelBuilder for
-compatibility with DBIx::Class::Schema::Loader version 0.07000
+DBIx::Class::Schema::Loader::RelBuilder::Compat::v0_06 - RelBuilder for
+compatibility with DBIx::Class::Schema::Loader version 0.06000
 
 =head1 DESCRIPTION
 
 See L<DBIx::Class::Schema::Loader::Base/naming> and
 L<DBIx::Class::Schema::Loader::RelBuilder>.
 
-=cut
-
-our $VERSION = '0.07015';
-
-sub _strip_id_postfix {
-    my ($self, $name) = @_;
-
-    $name =~ s/_id\z//;
-
-    return $name;
-}
-
 =head1 AUTHOR
 
 See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
